Class: Kombo::Models::Shared::AssessCandidateData

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Includes:
Crystalline::MetadataFields
Defined in:
lib/kombo/models/shared/assess_candidate_data.rb

Overview

References to the Candidate Assessment to be created or modified along with the data to be used in the creation or modification.

Instance Method Summary collapse

Methods included from Crystalline::MetadataFields

#field, #fields, included, #marshal_single, #to_dict, #to_json

Constructor Details

#initialize(candidate_assessment_data: nil) ⇒ AssessCandidateData

Returns a new instance of AssessCandidateData.



19
20
21
# File 'lib/kombo/models/shared/assess_candidate_data.rb', line 19

def initialize(candidate_assessment_data: nil)
  @candidate_assessment_data = candidate_assessment_data
end

Instance Method Details

#==(other) ⇒ Object



24
25
26
27
28
# File 'lib/kombo/models/shared/assess_candidate_data.rb', line 24

def ==(other)
  return false unless other.is_a? self.class
  return false unless @candidate_assessment_data == other.candidate_assessment_data
  true
end