Class: Kombo::Models::Shared::AssessmentTestStatusReference
- Inherits:
-
Object
- Object
- Kombo::Models::Shared::AssessmentTestStatusReference
- Extended by:
- T::Sig
- Includes:
- Crystalline::MetadataFields
- Defined in:
- lib/kombo/models/shared/assessment_test_status_reference.rb
Overview
A reference to the tenant supplied status for this Assessment Test Result. For example, if the test outcome was satisfactory or not.
Instance Method Summary collapse
- #==(other) ⇒ Object
-
#initialize(assessment_status_id:) ⇒ AssessmentTestStatusReference
constructor
A new instance of AssessmentTestStatusReference.
Methods included from Crystalline::MetadataFields
#field, #fields, included, #marshal_single, #to_dict, #to_json
Constructor Details
#initialize(assessment_status_id:) ⇒ AssessmentTestStatusReference
Returns a new instance of AssessmentTestStatusReference.
19 20 21 |
# File 'lib/kombo/models/shared/assessment_test_status_reference.rb', line 19 def initialize(assessment_status_id:) @assessment_status_id = assessment_status_id end |
Instance Method Details
#==(other) ⇒ Object
24 25 26 27 28 |
# File 'lib/kombo/models/shared/assessment_test_status_reference.rb', line 24 def ==(other) return false unless other.is_a? self.class return false unless @assessment_status_id == other.assessment_status_id true end |