Class: Kombo::Models::Shared::GetIntegrationsIntegrationIdPositiveResponseStatus

Inherits:
T::Enum
  • Object
show all
Defined in:
lib/kombo/models/shared/getintegrationsintegrationidpositiveresponse_status.rb

Overview

GetIntegrationsIntegrationIdPositiveResponseStatus - The current status of the integration.

  • ACTIVE: The integration is syncing data as expected.
  • INVALID: The integration has stopped syncing data because of invalid credentials. To fix this, reach out to your customer to reconnect the integration.
  • INACTIVE: The integration has stopped syncing as it's been manually set to inactive. You can enable it again in the integration's page.