Class: Kombo::Models::Shared::GetToolsCategoryPositiveResponseWriteActionCoverageStatus

Inherits:
T::Enum
  • Object
show all
Defined in:
lib/kombo/models/shared/gettoolscategorypositiveresponse_write_action_coverage_status.rb

Overview

GetToolsCategoryPositiveResponseWriteActionCoverageStatus - The status of a datapoint of an integrated tool:

  • ‘SUPPORTED`: the tool supports the datapoint and it can be used through Kombo.

  • ‘UNSUPPORTED`: the tool does not support the datapoint.

  • ‘NOT_IMPLEMENTED`: tool supports the datapoint but it was not integrated by Kombo for a given reason (see coverage grid).

  • ‘UNKNOWN`: the datapoint is not integrated yet and Kombo has no information about it’s availability in the tool.