Class: Kombo::Models::Shared::KomboAtsErrorCode
- Inherits:
-
T::Enum
- Object
- T::Enum
- Kombo::Models::Shared::KomboAtsErrorCode
- Defined in:
- lib/kombo/models/shared/komboatserror_code.rb
Overview
KomboAtsErrorCode - Some errors include an error code that can be used to identify their cause. See the Error Handling Docs for more information. For your error handling logic please use the error code instead of other properties (e.g. message, http status code, ...).