Class: Kombo::Models::Shared::KomboHrisErrorCode
- Inherits:
-
T::Enum
- Object
- T::Enum
- Kombo::Models::Shared::KomboHrisErrorCode
- Defined in:
- lib/kombo/models/shared/kombohriserror_code.rb
Overview
KomboHrisErrorCode - Some errors include an error code that can be used to identify their cause. See the [Error Handling Docs](docs.kombo.dev/guides/errors) for more information. For your error handling logic please use the error ‘code` instead of other properties (e.g. message, http status code, …).