Class: Kombo::Models::Shared::Name
- Inherits:
-
T::Enum
- Object
- T::Enum
- Kombo::Models::Shared::Name
- Defined in:
- lib/kombo/models/shared/name.rb
Overview
Name - The name of the Kombo model or connection that changed.
Name - The name of the Kombo model or connection that changed.