Class: Kombo::Models::Shared::PostAtsCandidatesCandidateIdResultLinksRequestBodyDetails

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Includes:
Crystalline::MetadataFields
Defined in:
lib/kombo/models/shared/postatscandidatescandidateidresultlinksrequestbody_details.rb

Overview

Additional details with attributes that will be added to the result. This can be percentages, scores, or any text.

We generally recommend using short attribute keys and a short custom_field_name_prefix to avoid overflowing the ATS UI.

Instance Method Summary collapse

Methods included from Crystalline::MetadataFields

#field, #fields, included, #marshal_single, #to_dict, #to_json

Constructor Details

#initialize(custom_field_name_prefix:, attributes:) ⇒ PostAtsCandidatesCandidateIdResultLinksRequestBodyDetails

Returns a new instance of PostAtsCandidatesCandidateIdResultLinksRequestBodyDetails.



23
24
25
26
# File 'lib/kombo/models/shared/postatscandidatescandidateidresultlinksrequestbody_details.rb', line 23

def initialize(custom_field_name_prefix:, attributes:)
  @custom_field_name_prefix = custom_field_name_prefix
  @attributes = attributes
end

Instance Method Details

#==(other) ⇒ Object



29
30
31
32
33
34
# File 'lib/kombo/models/shared/postatscandidatescandidateidresultlinksrequestbody_details.rb', line 29

def ==(other)
  return false unless other.is_a? self.class
  return false unless @custom_field_name_prefix == other.custom_field_name_prefix
  return false unless @attributes == other.attributes
  true
end