Class: Kombo::Models::Shared::PostAtsCandidatesRequestBodySalaryExpectations

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Includes:
Crystalline::MetadataFields
Defined in:
lib/kombo/models/shared/postatscandidatesrequestbody_salary_expectations.rb

Overview

The salary expectations of the applicant. We will automatically convert the amount to a format that is suitable for the ATS you are using. For example, if you are using monthly salary expectations, we will convert the amount to a yearly salary if the ATS expects yearly salary expectations.

Instance Method Summary collapse

Methods included from Crystalline::MetadataFields

#field, #fields, included, #marshal_single, #to_dict, #to_json

Constructor Details

#initialize(period:, amount:) ⇒ PostAtsCandidatesRequestBodySalaryExpectations

Returns a new instance of PostAtsCandidatesRequestBodySalaryExpectations.



21
22
23
24
# File 'lib/kombo/models/shared/postatscandidatesrequestbody_salary_expectations.rb', line 21

def initialize(period:, amount:)
  @period = period
  @amount = amount
end

Instance Method Details

#==(other) ⇒ Object



27
28
29
30
31
32
# File 'lib/kombo/models/shared/postatscandidatesrequestbody_salary_expectations.rb', line 27

def ==(other)
  return false unless other.is_a? self.class
  return false unless @period == other.period
  return false unless @amount == other.amount
  true
end