Class: Kombo::Models::Shared::PostAtsCandidatesRequestBodyWorkday

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Includes:
Crystalline::MetadataFields
Defined in:
lib/kombo/models/shared/postatscandidatesrequestbody_workday.rb

Overview

Fields specific to Workday. The remote fields schema follows the documentation at community.workday.com/sites/default/files/file-hosting/productionapi/Recruiting/v43.0/Put_Candidate.html. Only defined fields are supported, if you need additional field support please reach out to Kombo support.

Instance Method Summary collapse

Methods included from Crystalline::MetadataFields

#field, #fields, included, #marshal_single, #to_dict, #to_json

Constructor Details

#initialize(candidate_data: nil, override_source_reference_wid: nil) ⇒ PostAtsCandidatesRequestBodyWorkday

Returns a new instance of PostAtsCandidatesRequestBodyWorkday.



21
22
23
24
# File 'lib/kombo/models/shared/postatscandidatesrequestbody_workday.rb', line 21

def initialize(candidate_data: nil, override_source_reference_wid: nil)
  @candidate_data = candidate_data
  @override_source_reference_wid = override_source_reference_wid
end

Instance Method Details

#==(other) ⇒ Object



27
28
29
30
31
32
# File 'lib/kombo/models/shared/postatscandidatesrequestbody_workday.rb', line 27

def ==(other)
  return false unless other.is_a? self.class
  return false unless @candidate_data == other.candidate_data
  return false unless @override_source_reference_wid == other.override_source_reference_wid
  true
end