Class: Kombo::Models::Shared::PostAtsJobsJobIdApplicationsRequestBodySource Deprecated
- Inherits:
-
Object
- Object
- Kombo::Models::Shared::PostAtsJobsJobIdApplicationsRequestBodySource
- Extended by:
- T::Sig
- Includes:
- Crystalline::MetadataFields
- Defined in:
- lib/kombo/models/shared/postatsjobsjobidapplicationsrequestbody_source.rb
Overview
Deprecated.
class: This will be removed in a future release, please migrate away from it as soon as possible.
**(⚠️ Deprecated - Use [automatic source writing](/ats/features/application-attribution#automatic-attribution) instead)** Optional source information that will be attached to the candidate. If you’re a job board or recruiting service, you can use this to make sure your customers can see which candidates came from you.
This is deprecated because writing sources requires users to do some setup in most ATSs.
Instance Method Summary collapse
- #==(other) ⇒ Object
-
#initialize(name: nil, unified_key: nil, id: nil) ⇒ PostAtsJobsJobIdApplicationsRequestBodySource
constructor
A new instance of PostAtsJobsJobIdApplicationsRequestBodySource.
Methods included from Crystalline::MetadataFields
#field, #fields, included, #marshal_single, #to_dict, #to_json
Constructor Details
#initialize(name: nil, unified_key: nil, id: nil) ⇒ PostAtsJobsJobIdApplicationsRequestBodySource
Returns a new instance of PostAtsJobsJobIdApplicationsRequestBodySource.
29 30 31 32 33 |
# File 'lib/kombo/models/shared/postatsjobsjobidapplicationsrequestbody_source.rb', line 29 def initialize(name: nil, unified_key: nil, id: nil) @name = name @unified_key = unified_key @id = id end |
Instance Method Details
#==(other) ⇒ Object
36 37 38 39 40 41 42 |
# File 'lib/kombo/models/shared/postatsjobsjobidapplicationsrequestbody_source.rb', line 36 def ==(other) return false unless other.is_a? self.class return false unless @name == other.name return false unless @unified_key == other.unified_key return false unless @id == other.id true end |