Class: Kombo::Models::Shared::PostAtsJobsJobIdApplicationsRequestBodySourcedBy
- Inherits:
-
Object
- Object
- Kombo::Models::Shared::PostAtsJobsJobIdApplicationsRequestBodySourcedBy
- Extended by:
- T::Sig
- Includes:
- Crystalline::MetadataFields
- Defined in:
- lib/kombo/models/shared/postatsjobsjobidapplicationsrequestbody_sourced_by.rb
Overview
Credit the recruiter or team member who sourced this candidate.
While the ‘source` field tracks the channel/platform (e.g., “Awesome Jobboard”), the `sourced_by` field tracks the individual person responsible for finding the candidate.
Instance Method Summary collapse
- #==(other) ⇒ Object
-
#initialize(user_id:) ⇒ PostAtsJobsJobIdApplicationsRequestBodySourcedBy
constructor
A new instance of PostAtsJobsJobIdApplicationsRequestBodySourcedBy.
Methods included from Crystalline::MetadataFields
#field, #fields, included, #marshal_single, #to_dict, #to_json
Constructor Details
#initialize(user_id:) ⇒ PostAtsJobsJobIdApplicationsRequestBodySourcedBy
Returns a new instance of PostAtsJobsJobIdApplicationsRequestBodySourcedBy.
21 22 23 |
# File 'lib/kombo/models/shared/postatsjobsjobidapplicationsrequestbody_sourced_by.rb', line 21 def initialize(user_id:) @user_id = user_id end |
Instance Method Details
#==(other) ⇒ Object
26 27 28 29 30 |
# File 'lib/kombo/models/shared/postatsjobsjobidapplicationsrequestbody_sourced_by.rb', line 26 def ==(other) return false unless other.is_a? self.class return false unless @user_id == other.user_id true end |