Class: Kombo::Models::Shared::PostHrisAbsencesRequestBodyStatus

Inherits:
T::Enum
  • Object
show all
Defined in:
lib/kombo/models/shared/posthrisabsencesrequestbody_status.rb

Overview

PostHrisAbsencesRequestBodyStatus - The state that the absence should be created in. Some tools may approve absences automatically if they were created for an absence type that does not require approval.