Class: Kombo::Models::Shared::PostIntegrationsIntegrationIdSetupLinkRequestBodyLinkType

Inherits:
T::Enum
  • Object
show all
Defined in:
lib/kombo/models/shared/postintegrationsintegrationidsetuplinkrequestbody_link_type.rb

Overview

PostIntegrationsIntegrationIdSetupLinkRequestBodyLinkType - The type of link you want to create. EMBEDDED is for the embedded flow using the Kombo Connect SDK (these links are valid for 1 hour) and MAGIC_LINK is for magic links which you send out manually to customers (these are valid for 1 year).