Class: Kombo::Models::Shared::StageStatus

Inherits:
T::Enum
  • Object
show all
Defined in:
lib/kombo/models/shared/stage_status.rb

Overview

StageStatus - Whether the application stage is active in the ATS. Inactive stages (also e.g., archived or hidden) may still be referenced by existing applications but are typically not part of the current hiring workflow.