Class: Kombo::Models::Shared::DomesticBankRoutingType
- Inherits:
-
T::Enum
- Object
- T::Enum
- Kombo::Models::Shared::DomesticBankRoutingType
- Defined in:
- lib/kombo/models/shared/domestic_bank_routing_type.rb
Overview
DomesticBankRoutingType - Enum of the routing type, prefixed with the iso-3166-1-alpha-2 banks origin country. If there is uncertainty about the type, it will be set to null.