Class: Kombo::Models::Shared::GetAtsInterviewsPositiveResponseOutcome
- Inherits:
-
T::Enum
- Object
- T::Enum
- Kombo::Models::Shared::GetAtsInterviewsPositiveResponseOutcome
- Defined in:
- lib/kombo/models/shared/getatsinterviewspositiveresponse_outcome.rb
Overview
GetAtsInterviewsPositiveResponseOutcome - Parsed status of the application. If Kombo identifies that the application was accepted and the candidate hired, it will be ‘HIRED`. If the application was rejected or the candidate declined, it will be `DECLINED`. If the application is still in process, it will be `PENDING`. Kombo will always try to deliver this information as reliably as possible.