Class: Kombo::Models::Shared::KomboGeneralErrorCode

Inherits:
T::Enum
  • Object
show all
Defined in:
lib/kombo/models/shared/kombogeneralerror_code.rb

Overview

KomboGeneralErrorCode - Some errors include an error code that can be used to identify their cause. See the [Error Handling Docs](docs.kombo.dev/guides/errors) for more information. For your error handling logic please use the error ‘code` instead of other properties (e.g. message, http status code, …).