Class: Kombo::Models::Shared::PostAtsJobsJobIdApplicationsRequestBodyAnswerUnion

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Includes:
Crystalline::MetadataFields
Defined in:
lib/kombo/models/shared/postatsjobsjobidapplicationsrequestbody_answer_union.rb

Overview

Answer to a question. This will be validated based on the question format and throw an error if the answer is invalid. Here is a description of each question type and the required answer format:

‘TEXT` - Simply provide a “string” answer.

‘SINGLE_SELECT` - Provide the ID of the answer as a string.

‘MULTI_SELECT` - Provide a string array containing the question IDs of the selected options.

‘BOOLEAN` - Either `true` or `false`.

‘NUMBER` - A number.

‘DATE` - Provide the answer as an ISO 8601 date string.

‘FILE` - Please select Option 6 in the dropdown above to see the required format.

Instance Method Summary collapse

Methods included from Crystalline::MetadataFields

#field, #fields, included, #marshal_single, #to_dict, #to_json

Constructor Details

#initializePostAtsJobsJobIdApplicationsRequestBodyAnswerUnion

Returns a new instance of PostAtsJobsJobIdApplicationsRequestBodyAnswerUnion.



31
# File 'lib/kombo/models/shared/postatsjobsjobidapplicationsrequestbody_answer_union.rb', line 31

def initialize; end

Instance Method Details

#==(other) ⇒ Object



34
35
36
37
# File 'lib/kombo/models/shared/postatsjobsjobidapplicationsrequestbody_answer_union.rb', line 34

def ==(other)
  return false unless other.is_a? self.class
  true
end