Class: Kombo::Models::Shared::PostForceSyncPositiveResponseType
- Inherits:
-
T::Enum
- Object
- T::Enum
- Kombo::Models::Shared::PostForceSyncPositiveResponseType
- Defined in:
- lib/kombo/models/shared/postforcesyncpositiveresponse_type.rb
Overview
PostForceSyncPositiveResponseType - The type of the triggered sync. May differ from request, if the integration does not support delta syncs or if another sync is already running.