Class: Kombo::Models::Shared::PostIntegrationsIntegrationIdRelinkRequestBodyLinkType
- Inherits:
-
T::Enum
- Object
- T::Enum
- Kombo::Models::Shared::PostIntegrationsIntegrationIdRelinkRequestBodyLinkType
- Defined in:
- lib/kombo/models/shared/postintegrationsintegrationidrelinkrequestbody_link_type.rb
Overview
PostIntegrationsIntegrationIdRelinkRequestBodyLinkType - The type of link you want to create. EMBEDDED is for the embedded flow using the Kombo Connect SDK (these links are valid for 1 hour) and MAGIC_LINK is for magic links which you send out manually to customers (there are valid for 1 year).
This defaults to EMBEDDED, which is our recommended method of implementing the connection flow for a seamless user experience.